# kajson

## Introduction

Powerful universal JSON encoder/decoder for Python objects with support for pydantic v2.

This library is used by [Pipelex](https://github.com/Pipelex/pipelex), the open-source language for repeatable AI workflows, [check it out](https://github.com/Pipelex/pipelex).

## Installation

### Using pip

```bash
pip install kajson
```

### Using poetry

```bash
poetry add kajson
```

## Using uv (recommended)

```bash
uv pip install kajson
```

## Hat tip

This project is heavily based on code from [unijson](https://github.com/bpietropaoli/unijson) by Bastien Pietropaoli and distributed under the same license, [Apache 2.0](LICENSE).

---

"Pipelex" is a trademark of Evotis S.A.S.

© 2025 Evotis S.A.S.
